<?php

namespace Drupal\Tests\postoffice_twig\Kernel;

use Drupal\postoffice_test\Email\PostofficeTestEmail;
use Drupal\Tests\postoffice\Kernel\PostofficeTestBase;

/**
 * Covers postoffice twig extensions.
 *
 * @group postoffice
 */
class TwigExtensionTest extends PostofficeTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'postoffice_twig',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    // Setup custom theme.
    $this->container->get('theme_installer')->install(['stark', 'postoffice_twig_test_theme']);
    $this->config('system.theme')->set('default', 'postoffice_twig_test_theme')->save();
  }

  /**
   * Verify that the email subject can be set using a twig filter from a template.
   */
  public function testThemedEmailSubjectFilter() {
    $email = new PostofficeTestEmail('en', [
      '#theme' => 'postoffice_twig_test_subject_filter',
    ]);
    $recordedEmails = $this->callAndRecordEmails(function () use ($email) {
      $this->container->get('postoffice.mailer')->send($email);
    });

    $this->assertCount(1, $recordedEmails);
    $actual = $recordedEmails[0]->getSubject();
    $this->assertEquals('subject from twig filter', $actual);
  }

  /**
   * Verify that the email subject can be set using a twig function from a template.
   */
  public function testThemedEmailSubjectFunction() {
    $email = new PostofficeTestEmail('en', [
      '#theme' => 'postoffice_twig_test_subject_function',
    ]);
    $recordedEmails = $this->callAndRecordEmails(function () use ($email) {
      $this->container->get('postoffice.mailer')->send($email);
    });

    $this->assertCount(1, $recordedEmails);
    $actual = $recordedEmails[0]->getSubject();
    $this->assertEquals('subject from twig function', $actual);
  }

  /**
   * Verify that the text body can be set using a twig filter from a template.
   */
  public function testThemedEmailTextBody() {
    $email = new PostofficeTestEmail('en', [
      '#theme' => 'postoffice_twig_test_text_body',
    ]);
    $recordedEmails = $this->callAndRecordEmails(function () use ($email) {
      $this->container->get('postoffice.mailer')->send($email);
    });

    $this->assertCount(1, $recordedEmails);
    $actual = trim($recordedEmails[0]->getTextBody());
    $this->assertEquals('text part by test module', $actual);
  }

}
